@@ -7,6 +7,8 @@ start_message = "The lights have been turned on!"
 # This is what will appear in tips and help menus
 description = "Turns all of the lights on to a specfied color"
 
+default_speed = 0
+
 # This defines the format of update's 'state' parameter
 schema = {
     "color": {
@@ -22,5 +24,5 @@ schema = {
 #   step: The number of times that this effect has been updated
 #   state: Dict with information about the state of the effect
 def update(lights, step, state):
-    color = state["color"]
+    color = state["color"].get_color(step)
     lights.set_all_pixels(*color)
